'filesysobjects.PySourceInfo' - Module
**************************************

.. automodule:: filesysobjects.PySourceInfo

Functions
---------

getCallerFilePathName
^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerFilePathName

getCallerFileName
^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerFileName

getCallerFuncName
^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerFuncName

getCallerLinenumber
^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerLinenumber

getCallerName
^^^^^^^^^^^^^
	.. autofunction:: getCallerName

getCallerNameOID
^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerNameOID

getCallerPackageFilePathName
^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackageFilePathName

getCallerPackageName
^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackageName

getCallerPackagePathName
^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackagePathName

getCallerPackagePythonPath
^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackagePythonPath

getCallerModuleFilePathName
^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModuleFilePathName

getCallerModuleName
^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModuleName 

getCallerModulePathName
^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModulePathName

getCallerModulePythonPath
^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModulePythonPath

getPythonPathForPackage
^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getPythonPathForPackage

getPythonPathModuleRel
^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getPythonPathModuleRel

getPythonPathPrefixMatchFromSysPath
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getPythonPathPrefixMatchFromSysPath

getPythonPathRel
^^^^^^^^^^^^^^^^
	.. autofunction:: getPythonPathRel
